@@ -10,9 +10,6 @@ class LocalTestCommand(Command):
         if not hasattr(args, 'config') or not args.config:
             self.logger.error("❌ Config file is required for local tests")
             return False
-        if not hasattr(args, 'token') or not args.token:
-            self.logger.error("❌ Token is required for local tests")
-            return False
         return True
     
     def execute(self, args) -> int:
@@ -20,7 +17,7 @@ class LocalTestCommand(Command):
             if not self.validate_args(args):
                 return 1
                 
-            from osdu_perf.core.local_test_runner import LocalTestRunner
+            from osdu_perf.operations.local_test_operation import LocalTestRunner
             runner = LocalTestRunner(logger=self.logger)
             return runner.run_local_tests(args)
         except Exception as e:
